@@ -14,8 +14,9 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
-from typing import TYPE_CHECKING, Dict, Optional, Sequence, Tuple, Union
+from typing import TYPE_CHECKING, Sequence
 
 from google.api_core.exceptions import AlreadyExists, NotFound
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
@@ -32,19 +33,19 @@ from google.cloud.datacatalog import (
 )
 from google.protobuf.field_mask_pb2 import FieldMask
 
-from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.datacatalog import CloudDataCatalogHook
 from airflow.providers.google.cloud.links.datacatalog import (
     DataCatalogEntryGroupLink,
     DataCatalogEntryLink,
     DataCatalogTagTemplateLink,
 )
+from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
-class CloudDataCatalogCreateEntryOperator(BaseOperator):
+class CloudDataCatalogCreateEntryOperator(GoogleCloudBaseOperator):
     """
     Creates an entry.
 
@@ -101,13 +102,13 @@ class CloudDataCatalogCreateEntryOperator(BaseOperator):
         location: str,
         entry_group: str,
         entry_id: str,
-        entry: Union[Dict, Entry],
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        entry: dict | Entry,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -122,7 +123,7 @@ class CloudDataCatalogCreateEntryOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -162,7 +163,7 @@ class CloudDataCatalogCreateEntryOperator(BaseOperator):
         return Entry.to_dict(result)
 
 
-class CloudDataCatalogCreateEntryGroupOperator(BaseOperator):
+class CloudDataCatalogCreateEntryGroupOperator(GoogleCloudBaseOperator):
     """
     Creates an EntryGroup.
 
@@ -217,13 +218,13 @@ class CloudDataCatalogCreateEntryGroupOperator(BaseOperator):
         *,
         location: str,
         entry_group_id: str,
-        entry_group: Union[Dict, EntryGroup],
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        entry_group: dict | EntryGroup,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -237,7 +238,7 @@ class CloudDataCatalogCreateEntryGroupOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -275,7 +276,7 @@ class CloudDataCatalogCreateEntryGroupOperator(BaseOperator):
         return EntryGroup.to_dict(result)
 
 
-class CloudDataCatalogCreateTagOperator(BaseOperator):
+class CloudDataCatalogCreateTagOperator(GoogleCloudBaseOperator):
     """
     Creates a tag on an entry.
 
@@ -332,14 +333,14 @@ class CloudDataCatalogCreateTagOperator(BaseOperator):
         location: str,
         entry_group: str,
         entry: str,
-        tag: Union[Dict, Tag],
-        template_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        tag: dict | Tag,
+        template_id: str | None = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -355,7 +356,7 @@ class CloudDataCatalogCreateTagOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -411,7 +412,7 @@ class CloudDataCatalogCreateTagOperator(BaseOperator):
         return Tag.to_dict(tag)
 
 
-class CloudDataCatalogCreateTagTemplateOperator(BaseOperator):
+class CloudDataCatalogCreateTagTemplateOperator(GoogleCloudBaseOperator):
     """
     Creates a tag template.
 
@@ -464,13 +465,13 @@ class CloudDataCatalogCreateTagTemplateOperator(BaseOperator):
         *,
         location: str,
         tag_template_id: str,
-        tag_template: Union[Dict, TagTemplate],
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        tag_template: dict | TagTemplate,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -484,7 +485,7 @@ class CloudDataCatalogCreateTagTemplateOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -521,7 +522,7 @@ class CloudDataCatalogCreateTagTemplateOperator(BaseOperator):
         return TagTemplate.to_dict(result)
 
 
-class CloudDataCatalogCreateTagTemplateFieldOperator(BaseOperator):
+class CloudDataCatalogCreateTagTemplateFieldOperator(GoogleCloudBaseOperator):
     r"""
     Creates a field in a tag template.
 
@@ -580,13 +581,13 @@ class CloudDataCatalogCreateTagTemplateFieldOperator(BaseOperator):
         location: str,
         tag_template: str,
         tag_template_field_id: str,
-        tag_template_field: Union[Dict, TagTemplateField],
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        tag_template_field: dict | TagTemplateField,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -601,7 +602,7 @@ class CloudDataCatalogCreateTagTemplateFieldOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -640,7 +641,7 @@ class CloudDataCatalogCreateTagTemplateFieldOperator(BaseOperator):
         return TagTemplateField.to_dict(result)
 
 
-class CloudDataCatalogDeleteEntryOperator(BaseOperator):
+class CloudDataCatalogDeleteEntryOperator(GoogleCloudBaseOperator):
     """
     Deletes an existing entry.
 
@@ -688,12 +689,12 @@ class CloudDataCatalogDeleteEntryOperator(BaseOperator):
         location: str,
         entry_group: str,
         entry: str,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -707,7 +708,7 @@ class CloudDataCatalogDeleteEntryOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -725,7 +726,7 @@ class CloudDataCatalogDeleteEntryOperator(BaseOperator):
             self.log.info("Entry doesn't exists. Skipping.")
 
 
-class CloudDataCatalogDeleteEntryGroupOperator(BaseOperator):
+class CloudDataCatalogDeleteEntryGroupOperator(GoogleCloudBaseOperator):
     """
     Deletes an EntryGroup.
 
@@ -772,12 +773,12 @@ class CloudDataCatalogDeleteEntryGroupOperator(BaseOperator):
         *,
         location: str,
         entry_group: str,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -790,7 +791,7 @@ class CloudDataCatalogDeleteEntryGroupOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -807,7 +808,7 @@ class CloudDataCatalogDeleteEntryGroupOperator(BaseOperator):
             self.log.info("Entry doesn't exists. skipping")
 
 
-class CloudDataCatalogDeleteTagOperator(BaseOperator):
+class CloudDataCatalogDeleteTagOperator(GoogleCloudBaseOperator):
     """
     Deletes a tag.
 
@@ -858,12 +859,12 @@ class CloudDataCatalogDeleteTagOperator(BaseOperator):
         entry_group: str,
         entry: str,
         tag: str,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -878,7 +879,7 @@ class CloudDataCatalogDeleteTagOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -897,7 +898,7 @@ class CloudDataCatalogDeleteTagOperator(BaseOperator):
             self.log.info("Entry doesn't exists. skipping")
 
 
-class CloudDataCatalogDeleteTagTemplateOperator(BaseOperator):
+class CloudDataCatalogDeleteTagTemplateOperator(GoogleCloudBaseOperator):
     """
     Deletes a tag template and all tags using the template.
 
@@ -947,12 +948,12 @@ class CloudDataCatalogDeleteTagTemplateOperator(BaseOperator):
         location: str,
         tag_template: str,
         force: bool,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -966,7 +967,7 @@ class CloudDataCatalogDeleteTagTemplateOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -984,7 +985,7 @@ class CloudDataCatalogDeleteTagTemplateOperator(BaseOperator):
             self.log.info("Tag Template doesn't exists. skipping")
 
 
-class CloudDataCatalogDeleteTagTemplateFieldOperator(BaseOperator):
+class CloudDataCatalogDeleteTagTemplateFieldOperator(GoogleCloudBaseOperator):
     """
     Deletes a field in a tag template and all uses of that field.
 
@@ -1035,12 +1036,12 @@ class CloudDataCatalogDeleteTagTemplateFieldOperator(BaseOperator):
         tag_template: str,
         field: str,
         force: bool,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1055,7 +1056,7 @@ class CloudDataCatalogDeleteTagTemplateFieldOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1074,7 +1075,7 @@ class CloudDataCatalogDeleteTagTemplateFieldOperator(BaseOperator):
             self.log.info("Tag Template field doesn't exists. skipping")
 
 
-class CloudDataCatalogGetEntryOperator(BaseOperator):
+class CloudDataCatalogGetEntryOperator(GoogleCloudBaseOperator):
     """
     Gets an entry.
 
@@ -1123,12 +1124,12 @@ class CloudDataCatalogGetEntryOperator(BaseOperator):
         location: str,
         entry_group: str,
         entry: str,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1142,7 +1143,7 @@ class CloudDataCatalogGetEntryOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> dict:
+    def execute(self, context: Context) -> dict:
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1166,7 +1167,7 @@ class CloudDataCatalogGetEntryOperator(BaseOperator):
         return Entry.to_dict(result)
 
 
-class CloudDataCatalogGetEntryGroupOperator(BaseOperator):
+class CloudDataCatalogGetEntryGroupOperator(GoogleCloudBaseOperator):
     """
     Gets an entry group.
 
@@ -1218,12 +1219,12 @@ class CloudDataCatalogGetEntryGroupOperator(BaseOperator):
         location: str,
         entry_group: str,
         read_mask: FieldMask,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1237,7 +1238,7 @@ class CloudDataCatalogGetEntryGroupOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> dict:
+    def execute(self, context: Context) -> dict:
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1260,7 +1261,7 @@ class CloudDataCatalogGetEntryGroupOperator(BaseOperator):
         return EntryGroup.to_dict(result)
 
 
-class CloudDataCatalogGetTagTemplateOperator(BaseOperator):
+class CloudDataCatalogGetTagTemplateOperator(GoogleCloudBaseOperator):
     """
     Gets a tag template.
 
@@ -1306,12 +1307,12 @@ class CloudDataCatalogGetTagTemplateOperator(BaseOperator):
         *,
         location: str,
         tag_template: str,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1324,7 +1325,7 @@ class CloudDataCatalogGetTagTemplateOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> dict:
+    def execute(self, context: Context) -> dict:
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1346,7 +1347,7 @@ class CloudDataCatalogGetTagTemplateOperator(BaseOperator):
         return TagTemplate.to_dict(result)
 
 
-class CloudDataCatalogListTagsOperator(BaseOperator):
+class CloudDataCatalogListTagsOperator(GoogleCloudBaseOperator):
     """
     Lists the tags on an Entry.
 
@@ -1401,12 +1402,12 @@ class CloudDataCatalogListTagsOperator(BaseOperator):
         entry_group: str,
         entry: str,
         page_size: int = 100,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1421,7 +1422,7 @@ class CloudDataCatalogListTagsOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> list:
+    def execute(self, context: Context) -> list:
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1446,7 +1447,7 @@ class CloudDataCatalogListTagsOperator(BaseOperator):
         return [Tag.to_dict(item) for item in result]
 
 
-class CloudDataCatalogLookupEntryOperator(BaseOperator):
+class CloudDataCatalogLookupEntryOperator(GoogleCloudBaseOperator):
     r"""
     Get an entry by target resource name.
 
@@ -1493,14 +1494,14 @@ class CloudDataCatalogLookupEntryOperator(BaseOperator):
     def __init__(
         self,
         *,
-        linked_resource: Optional[str] = None,
-        sql_resource: Optional[str] = None,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        linked_resource: str | None = None,
+        sql_resource: str | None = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1513,7 +1514,7 @@ class CloudDataCatalogLookupEntryOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> dict:
+    def execute(self, context: Context) -> dict:
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1525,7 +1526,7 @@ class CloudDataCatalogLookupEntryOperator(BaseOperator):
             metadata=self.metadata,
         )
 
-        project_id, location_id, entry_group_id, entry_id = result.name.split('/')[1::2]
+        project_id, location_id, entry_group_id, entry_id = result.name.split("/")[1::2]
         DataCatalogEntryLink.persist(
             context=context,
             task_instance=self,
@@ -1537,7 +1538,7 @@ class CloudDataCatalogLookupEntryOperator(BaseOperator):
         return Entry.to_dict(result)
 
 
-class CloudDataCatalogRenameTagTemplateFieldOperator(BaseOperator):
+class CloudDataCatalogRenameTagTemplateFieldOperator(GoogleCloudBaseOperator):
     """
     Renames a field in a tag template.
 
@@ -1591,12 +1592,12 @@ class CloudDataCatalogRenameTagTemplateFieldOperator(BaseOperator):
         tag_template: str,
         field: str,
         new_tag_template_field_id: str,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1611,7 +1612,7 @@ class CloudDataCatalogRenameTagTemplateFieldOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1634,7 +1635,7 @@ class CloudDataCatalogRenameTagTemplateFieldOperator(BaseOperator):
         )
 
 
-class CloudDataCatalogSearchCatalogOperator(BaseOperator):
+class CloudDataCatalogSearchCatalogOperator(GoogleCloudBaseOperator):
     r"""
     Searches Data Catalog for multiple resources like entries, tags that match a query.
 
@@ -1706,15 +1707,15 @@ class CloudDataCatalogSearchCatalogOperator(BaseOperator):
     def __init__(
         self,
         *,
-        scope: Union[Dict, SearchCatalogRequest.Scope],
+        scope: dict | SearchCatalogRequest.Scope,
         query: str,
         page_size: int = 100,
-        order_by: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        order_by: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1728,7 +1729,7 @@ class CloudDataCatalogSearchCatalogOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> list:
+    def execute(self, context: Context) -> list:
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1744,7 +1745,7 @@ class CloudDataCatalogSearchCatalogOperator(BaseOperator):
         return [SearchCatalogResult.to_dict(item) for item in result]
 
 
-class CloudDataCatalogUpdateEntryOperator(BaseOperator):
+class CloudDataCatalogUpdateEntryOperator(GoogleCloudBaseOperator):
     """
     Updates an existing entry.
 
@@ -1801,17 +1802,17 @@ class CloudDataCatalogUpdateEntryOperator(BaseOperator):
     def __init__(
         self,
         *,
-        entry: Union[Dict, Entry],
-        update_mask: Union[Dict, FieldMask],
-        location: Optional[str] = None,
-        entry_group: Optional[str] = None,
-        entry_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        entry: dict | Entry,
+        update_mask: dict | FieldMask,
+        location: str | None = None,
+        entry_group: str | None = None,
+        entry_id: str | None = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1827,7 +1828,7 @@ class CloudDataCatalogUpdateEntryOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1854,7 +1855,7 @@ class CloudDataCatalogUpdateEntryOperator(BaseOperator):
         )
 
 
-class CloudDataCatalogUpdateTagOperator(BaseOperator):
+class CloudDataCatalogUpdateTagOperator(GoogleCloudBaseOperator):
     """
     Updates an existing tag.
 
@@ -1912,18 +1913,18 @@ class CloudDataCatalogUpdateTagOperator(BaseOperator):
     def __init__(
         self,
         *,
-        tag: Union[Dict, Tag],
-        update_mask: Union[Dict, FieldMask],
-        location: Optional[str] = None,
-        entry_group: Optional[str] = None,
-        entry: Optional[str] = None,
-        tag_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        tag: dict | Tag,
+        update_mask: dict | FieldMask,
+        location: str | None = None,
+        entry_group: str | None = None,
+        entry: str | None = None,
+        tag_id: str | None = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1940,7 +1941,7 @@ class CloudDataCatalogUpdateTagOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1968,7 +1969,7 @@ class CloudDataCatalogUpdateTagOperator(BaseOperator):
         )
 
 
-class CloudDataCatalogUpdateTagTemplateOperator(BaseOperator):
+class CloudDataCatalogUpdateTagTemplateOperator(GoogleCloudBaseOperator):
     """
     Updates a tag template.
 
@@ -2028,16 +2029,16 @@ class CloudDataCatalogUpdateTagTemplateOperator(BaseOperator):
     def __init__(
         self,
         *,
-        tag_template: Union[Dict, TagTemplate],
-        update_mask: Union[Dict, FieldMask],
-        location: Optional[str] = None,
-        tag_template_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        tag_template: dict | TagTemplate,
+        update_mask: dict | FieldMask,
+        location: str | None = None,
+        tag_template_id: str | None = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -2052,7 +2053,7 @@ class CloudDataCatalogUpdateTagTemplateOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -2077,7 +2078,7 @@ class CloudDataCatalogUpdateTagTemplateOperator(BaseOperator):
         )
 
 
-class CloudDataCatalogUpdateTagTemplateFieldOperator(BaseOperator):
+class CloudDataCatalogUpdateTagTemplateFieldOperator(GoogleCloudBaseOperator):
     """
     Updates a field in a tag template. This method cannot be used to update the field type.
 
@@ -2143,18 +2144,18 @@ class CloudDataCatalogUpdateTagTemplateFieldOperator(BaseOperator):
     def __init__(
         self,
         *,
-        tag_template_field: Union[Dict, TagTemplateField],
-        update_mask: Union[Dict, FieldMask],
-        tag_template_field_name: Optional[str] = None,
-        location: Optional[str] = None,
-        tag_template: Optional[str] = None,
-        tag_template_field_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        tag_template_field: dict | TagTemplateField,
+        update_mask: dict | FieldMask,
+        tag_template_field_name: str | None = None,
+        location: str | None = None,
+        tag_template: str | None = None,
+        tag_template_field_id: str | None = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -2171,7 +2172,7 @@ class CloudDataCatalogUpdateTagTemplateFieldOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudDataCatalogHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
